@@ -54,8 +54,9 @@ class TD:
         self.broker_token = broker_token
         self.hist_data = {}
         self.live_data = {}
+        self.min_live_data = {}
         self.symbol_mkt_id_map = defaultdict(set)
-        self.streaming_symbols = {}
+        # self.streaming_symbols = {}
         self.touchline_data = {}
         self.default_market_data_id = 2000
         self.default_historical_data_id = 1000
@@ -218,21 +219,29 @@ class TD:
         else:
             req_ids = self.get_req_id_list(self.default_market_data_id, len(resolved_contracts))
             self.default_market_data_id = self.default_market_data_id + len(resolved_contracts)
+        symbols_to_call = []
         for j in range(0, len(req_ids)):
             resolved_contract = resolved_contracts[j].upper()
             self.touchline_data[req_ids[j]] = TouchlineData()
             if self.live_websocket.subscription_type == 'tick':
-                self.live_data[req_ids[j]] = TickLiveData(resolved_contract)
+                if req_ids[j] not in self.live_data.keys() or type(self.live_data[req_ids[j]]) != TickLiveData:
+                    self.live_data[req_ids[j]] = TickLiveData(resolved_contract)
             elif '+' in self.live_websocket.subscription_type:
-                self.live_data[req_ids[j]] = TickLiveData(resolved_contract)
-                self.live_data[req_ids[j]] = MinLiveData(resolved_contract)
+                if req_ids[j] not in self.live_data.keys() or type(self.live_data[req_ids[j]]) != TickLiveData:
+                    self.live_data[req_ids[j]] = TickLiveData(resolved_contract)
+                if req_ids[j] not in self.min_live_data.keys() or type(self.min_live_data[req_ids[j]]) != MinLiveData:
+                    self.min_live_data[req_ids[j]] = MinLiveData(resolved_contract)
             elif 'min' in self.live_websocket.subscription_type:
-                self.live_data[req_ids[j]] = MinLiveData(resolved_contract)
+                if req_ids[j] not in self.live_data.keys() or type(self.live_data[req_ids[j]]) != MinLiveData:
+                    self.live_data[req_ids[j]] = MinLiveData(resolved_contract)
+            if resolved_contract not in self.symbol_mkt_id_map.keys():
+                symbols_to_call.append(resolved_contract)
             self.symbol_mkt_id_map[resolved_contract].update({req_ids[j]})
-        self.live_websocket.send(f'{{"method": "addsymbol", "symbols": {json.dumps(resolved_contracts)}}}')
+        if len(symbols_to_call) > 0:
+            self.live_websocket.send(f'{{"method": "addsymbol", "symbols": {json.dumps(symbols_to_call)}}}')
         return req_ids
 
-    def stop_live_data(self, contracts):
+    def stop_live_data(self, contracts):  # Clearing objects is done after server confirmation
         self.live_websocket.send(f'{{"method": "removesymbol", "symbols": {json.dumps(contracts)}}}')
 
     # def get_touchline(self):
