@@ -5,6 +5,7 @@ from dateutil.relativedelta import relativedelta
 import time
 import json
 from copy import deepcopy
+from collections import defaultdict
 
 from colorama import Style, Fore
 
@@ -123,7 +124,10 @@ class LiveClient(WebSocketApp):
             contract = contract_info.split(':')[0]
             for req_id in self.parent_app.symbol_mkt_id_map[contract.upper()]:
                 del self.parent_app.live_data[req_id]
-            del self.parent_app.symbol_mkt_id_map[contract.upper()]
+                del self.parent_app.touchline_data[req_id]
+                self.parent_app.symbol_mkt_id_map[contract.upper()].remove(req_id)
+                if '+' in self.subscription_type:
+                    del self.parent_app.min_live_data[req_id]
 
     def add_contract_details(self, contracts_list):
         for contract_details in contracts_list:
@@ -150,6 +154,9 @@ class LiveClient(WebSocketApp):
                     self.parent_app.touchline_data[ticker_id].best_ask_price = float(contract_details[16])
                     self.parent_app.touchline_data[ticker_id].best_ask_qty = float(contract_details[17])
                     self.parent_app.live_data[ticker_id].populate_using_touchline(self.parent_app.live_data[ticker_id], self.parent_app.touchline_data[ticker_id])
+                    if '+' in self.subscription_type:
+                        self.parent_app.min_live_data[ticker_id].populate_using_touchline(self.parent_app.min_live_data[ticker_id], self.parent_app.touchline_data[ticker_id])
+
                 # print(f"Updated touchline data for {symbol} and related live data objects...") #  self.logger.info
             else:
                 self.logger.debug(f'{Style.BRIGHT}{Fore.YELLOW}Probable repeated symbol...{Style.RESET_ALL}')
@@ -223,20 +230,23 @@ class LiveClient(WebSocketApp):
         try:
             symbol = self.contract_mapping[int(bar_data[0])]
             for ticker_id in self.parent_app.symbol_mkt_id_map[symbol]:
-                # Assigning new data
-                self.parent_app.live_data[ticker_id].symbol_id = int(bar_data[0])
-                self.parent_app.live_data[ticker_id].timestamp = datetime.strptime(bar_data[1], '%Y-%m-%dT%H:%M:%S')
-                self.parent_app.live_data[ticker_id].symbol = symbol
-                self.parent_app.live_data[ticker_id].open = float(bar_data[2])
-                self.parent_app.live_data[ticker_id].high = bar_high = float(bar_data[3])
-                if bar_high > self.parent_app.live_data[ticker_id].day_high:
-                    self.parent_app.live_data[ticker_id].day_high = self.parent_app.touchline_data[ticker_id].high = bar_high
-                self.parent_app.live_data[ticker_id].low = bar_low = float(bar_data[4])
-                if bar_low < self.parent_app.live_data[ticker_id].day_low:
-                    self.parent_app.live_data[ticker_id].day_low = self.parent_app.touchline_data[ticker_id].low = bar_low
-                self.parent_app.live_data[ticker_id].close = self.parent_app.touchline_data[ticker_id].ltp = float(bar_data[5])
-                self.parent_app.live_data[ticker_id].volume = float(bar_data[6])
-                self.parent_app.live_data[ticker_id].oi = float(bar_data[7])
+                if '+' in self.subscription_type:
+                    obj_to_edit = self.parent_app.min_live_data[ticker_id]
+                else:
+                    obj_to_edit = self.parent_app.live_data[ticker_id]
+                obj_to_edit.symbol_id = int(bar_data[0])
+                obj_to_edit.timestamp = datetime.strptime(bar_data[1], '%Y-%m-%dT%H:%M:%S')
+                obj_to_edit.symbol = symbol
+                obj_to_edit.open = float(bar_data[2])
+                obj_to_edit.high = bar_high = float(bar_data[3])
+                if bar_high > obj_to_edit.day_high:
+                    obj_to_edit.day_high = self.parent_app.touchline_data[ticker_id].high = bar_high
+                obj_to_edit.low = bar_low = float(bar_data[4])
+                if bar_low < obj_to_edit.day_low:
+                    obj_to_edit.day_low = self.parent_app.touchline_data[ticker_id].low = bar_low
+                obj_to_edit.close = self.parent_app.touchline_data[ticker_id].ltp = float(bar_data[5])
+                obj_to_edit.volume = float(bar_data[6])
+                obj_to_edit.oi = float(bar_data[7])
         except KeyError:
             pass
         except Exception as e:
@@ -253,8 +263,17 @@ class LiveClient(WebSocketApp):
         self.sock.ping()
         self.sock.settimeout(15)
         if self.parent_app.symbol_mkt_id_map:
-            print('Some data needs resuming here')
-            # print(self.parent_app.symbol_mkt_id_map)
+            old_symbol_map = temp_symbol_map = deepcopy(self.parent_app.symbol_mkt_id_map)  # temp_symbol_map is destructed while restarting the data
+            temp_symbol_map = dict(temp_symbol_map)
+            self.parent_app.symbol_mkt_id_map = defaultdict(set)
+            print(f'{list(temp_symbol_map.keys())} needs resuming here.')
+            while temp_symbol_map:
+                restart_symbols = list(temp_symbol_map.keys())
+                restart_req_ids = [temp_symbol_map[symbol].pop() for symbol in restart_symbols]
+                self.parent_app.start_live_data(restart_symbols, req_id=restart_req_ids)
+                temp_symbol_map = {symbol: symbol_set for (symbol, symbol_set) in temp_symbol_map.items() if symbol_set}
+            assert old_symbol_map == self.parent_app.symbol_mkt_id_map
+            print(f'All streaming symbols have been resumed.')
 
     def ws_close(self, *args):
         # self.logger.error('Live WebSocket Closed')
